@@ -10,7 +10,7 @@ except DistributionNotFound:
 from . import differentiation
 from . import feature_library
 from . import optimizers
-from . import scikit_time
+from . import deeptime
 from . import utils
 from .pysindy import SINDy
 from .differentiation import BaseDifferentiation
@@ -23,6 +23,7 @@ from .feature_library import FourierLibrary
 from .feature_library import IdentityLibrary
 from .feature_library import PolynomialLibrary
 from .optimizers import BaseOptimizer
+from .optimizers import ConstrainedSR3
 from .optimizers import SINDyOptimizer
 from .optimizers import SR3
 from .optimizers import STLSQ
@@ -33,4 +34,4 @@ __all__.extend(differentiation.__all__)
 __all__.extend(feature_library.__all__)
 __all__.extend(optimizers.__all__)
 __all__.extend(["utils"])
-__all__.extend(["scikit_time"])
+__all__.extend(["deeptime"])
