@@ -1,7 +1,7 @@
 from sklearn.utils import check_array
 from sklearn.utils.validation import check_is_fitted
 
-from .feature_library import BaseFeatureLibrary
+from .base import BaseFeatureLibrary
 
 
 class IdentityLibrary(BaseFeatureLibrary):
