@@ -1,6 +1,7 @@
 from .base import BaseOptimizer
+from .constrained_sr3 import ConstrainedSR3
 from .sindy_optimizer import SINDyOptimizer
 from .sr3 import SR3
 from .stlsq import STLSQ
 
-__all__ = ["BaseOptimizer", "SINDyOptimizer", "SR3", "STLSQ"]
+__all__ = ["BaseOptimizer", "ConstrainedSR3", "SINDyOptimizer", "SR3", "STLSQ"]
