@@ -20,33 +20,34 @@ from .differentiation import FiniteDifference
 from .feature_library import PolynomialLibrary
 from .optimizers import SINDyOptimizer
 from .optimizers import STLSQ
-from .utils.base import drop_nan_rows
-from .utils.base import equations
-from .utils.base import validate_control_variables
-from .utils.base import validate_input
+from .utils import drop_nan_rows
+from .utils import equations
+from .utils import validate_control_variables
+from .utils import validate_input
 
 
 class SINDy(BaseEstimator):
     """
-    SINDy model object.
+    Sparse Identification of Nonlinear Dynamical Systems (SINDy).
+    Uses sparse regression to learn a dynamical systems model from measurement data.
 
     Parameters
     ----------
     optimizer : optimizer object, optional
-        Optimization method used to fit the SINDy model. This must be an object
-        extending the ``pysindy.optimizers.BaseOptimizer`` class. Default is
-        sequentially thresholded least squares with a threshold of 0.1.
+        Optimization method used to fit the SINDy model. This must be a class
+        extending :class:`pysindy.optimizers.BaseOptimizer`.
+        The default is :class:`STLSQ`.
 
     feature_library : feature library object, optional
         Feature library object used to specify candidate right-hand side features.
-        This must be an object extending the
-        ``pysindy.feature_library.BaseFeatureLibrary`` class.
-        Default is polynomial features of degree 2.
+        This must be a class extending
+        :class:`pysindy.feature_library.base.BaseFeatureLibrary`.
+        The default option is :class:`PolynomialLibrary`.
 
     differentiation_method : differentiation object, optional
-        Method for differentiating the data. This must be an object extending
-        the ``pysindy.differentiation_methods.BaseDifferentiation`` class.
-        Default is centered difference.
+        Method for differentiating the data. This must be a class extending
+        :class:`pysindy.differentiation_methods.base.BaseDifferentiation` class.
+        The default option is centered difference.
 
     feature_names : list of string, length n_input_features, optional
         Names for the input features (e.g. ``['x', 'y', 'z']``). If None, will use
@@ -63,7 +64,7 @@ class SINDy(BaseEstimator):
 
     Attributes
     ----------
-    model : sklearn.multioutput.MultiOutputRegressor object
+    model : ``sklearn.multioutput.MultiOutputRegressor`` object
         The fitted SINDy model.
 
     n_input_features_ : int
@@ -176,7 +177,7 @@ class SINDy(BaseEstimator):
         quiet=False,
     ):
         """
-        Fit the SINDy model.
+        Fit a SINDy model.
 
         Parameters
         ----------
@@ -222,10 +223,10 @@ class SINDy(BaseEstimator):
         unbias: boolean, optional (default True)
             Whether to perform an extra step of unregularized linear regression to
             unbias the coefficients for the identified support.
-            If the optimizer (``SINDy.optimizer``) applies any type of regularization,
+            If the optimizer (``self.optimizer``) applies any type of regularization,
             that regularization may bias coefficients toward particular values,
             improving the conditioning of the problem but harming the quality of the
-            fit. Setting ``unbias=True`` enables an extra step wherein unregularized
+            fit. Setting ``unbias==True`` enables an extra step wherein unregularized
             linear regression is applied, but only for the coefficients in the support
             identified by the optimizer. This helps to remove the bias introduced by
             regularization.
@@ -235,7 +236,7 @@ class SINDy(BaseEstimator):
 
         Returns
         -------
-        self: returns an instance of self
+        self: a fitted :class:`SINDy` instance
         """
         if t is None:
             t = self.t_default
@@ -275,6 +276,9 @@ class SINDy(BaseEstimator):
         # Drop rows where derivative isn't known
         x, x_dot = drop_nan_rows(x, x_dot)
 
+        if hasattr(self.optimizer, "unbias"):
+            unbias = self.optimizer.unbias
+
         optimizer = SINDyOptimizer(self.optimizer, unbias=unbias)
         steps = [("features", self.feature_library), ("model", optimizer)]
         self.model = Pipeline(steps)
@@ -311,7 +315,7 @@ class SINDy(BaseEstimator):
 
         u: array-like or list of array-like, shape(n_samples, n_control_features), \
                 (default None)
-            Control variables. If ``multiple_trajectories=True`` then u
+            Control variables. If ``multiple_trajectories==True`` then u
             must be a list of control variable data from each trajectory. If the
             model was fit with control variables then u is not optional.
 
@@ -363,13 +367,14 @@ class SINDy(BaseEstimator):
         Parameters
         ----------
         precision: int, optional (default 3)
-            Number of decimal points to print for each coefficient in the
+            Number of decimal points to include for each coefficient in the
             equation.
 
         Returns
         -------
         equations: list of strings
-            Strings containing the SINDy model equation for each input feature.
+            List of strings representing the SINDy model equations for each
+            input feature.
         """
         check_is_fitted(self, "model")
         if self.discrete_time:
@@ -417,7 +422,7 @@ class SINDy(BaseEstimator):
         Parameters
         ----------
         x: array-like or list of array-like, shape (n_samples, n_input_features)
-            Samples
+            Samples from which to make predictions.
 
         t: float, numpy array of shape (n_samples,), or list of numpy arrays, optional \
                 (default None)
@@ -435,7 +440,7 @@ class SINDy(BaseEstimator):
 
         u: array-like or list of array-like, shape(n_samples, n_control_features), \
                 optional (default None)
-            Control variables. If ``multiple_trajectories=True`` then u
+            Control variables. If ``multiple_trajectories==True`` then u
             must be a list of control variable data from each trajectory.
             If the model was fit with control variables then u is not optional.
 
@@ -509,6 +514,41 @@ class SINDy(BaseEstimator):
         """
         Handle input data that contains multiple trajectories by doing the
         necessary validation, reshaping, and computation of derivatives.
+
+        This method essentially just loops over elements of each list in parallel,
+        validates them, and (optionally) concatenates them together.
+
+        Parameters
+        ----------
+        x: list of np.ndarray
+            List of measurements, with each entry corresponding to a different
+            trajectory.
+
+        t: list of np.ndarray or int
+            List of time points for different trajectories.
+            If a list of ints is passed, each entry is assumed to be the timestep
+            for the corresponding trajectory in x.
+
+        x_dot: list of np.ndarray
+            List of derivative measurements, with each entry corresponding to a
+            different trajectory. If None, the derivatives will be approximated
+            from x.
+
+        return_array: boolean, optional (default True)
+            Whether to return concatenated np.ndarrays.
+            If False, the outputs will be lists with an entry for each trajectory.
+
+        Returns
+        -------
+        x_out: np.ndarray or list
+            Validated version of x. If return_array is True, x_out will be an
+            np.ndarray of concatenated trajectories. If False, x_out will be
+            a list.
+
+        x_dot_out: np.ndarray or list
+            Validated derivative measurements.If return_array is True, x_dot_out
+            will be an np.ndarray of concatenated trajectories.
+            If False, x_out will be a list.
         """
         if not isinstance(x, Sequence):
             raise TypeError("Input x must be a list")
@@ -555,7 +595,8 @@ class SINDy(BaseEstimator):
 
     def differentiate(self, x, t=None, multiple_trajectories=False):
         """
-        Apply the model's differentiation method to data.
+        Apply the model's differentiation method
+        (:code:`self.differentiation_method`) to data.
 
         Parameters
         ----------
@@ -591,12 +632,28 @@ class SINDy(BaseEstimator):
             return self.differentiation_method(x, t)
 
     def coefficients(self):
-        """Return a list of the coefficients learned by SINDy model."""
+        """
+        Get an array of the coefficients learned by SINDy model.
+
+        Returns
+        -------
+        coef: np.ndarray, shape (n_input_features, n_output_features)
+            Learned coefficients of the SINDy model.
+            Equivalent to :math:`\\Xi^\\top` in the literature.
+        """
         check_is_fitted(self, "model")
         return self.model.steps[-1][1].coef_
 
     def get_feature_names(self):
-        """Return a list of names of features used by SINDy model."""
+        """
+        Get a list of names of features used by SINDy model.
+
+        Returns
+        -------
+        feats: list
+            A list of strings giving the names of the features in the feature
+            library, :code:`self.feature_library`.
+        """
         check_is_fitted(self, "model")
         return self.model.steps[0][1].get_feature_names(
             input_features=self.feature_names
@@ -722,7 +779,9 @@ class SINDy(BaseEstimator):
             else:
                 if not callable(u):
                     if interpolator is None:
-                        u_fun = interp1d(t, u, axis=0, kind="cubic")
+                        u_fun = interp1d(
+                            t, u, axis=0, kind="cubic", fill_value="extrapolate"
+                        )
                     else:
                         u_fun = interpolator(t, u, **interpolator_kws)
 
@@ -749,4 +808,7 @@ class SINDy(BaseEstimator):
 
     @property
     def complexity(self):
+        """
+        Complexity of the model measured as the number of nonzero parameters.
+        """
         return self.model.steps[-1][1].complexity
