@@ -1,22 +1,28 @@
+from .base import capped_simplex_projection
 from .base import drop_nan_rows
 from .base import equations
 from .base import get_prox
+from .base import get_regularization
 from .base import print_model
 from .base import prox_cad
 from .base import prox_l0
 from .base import prox_l1
+from .base import reorder_constraints
 from .base import supports_multiple_targets
 from .base import validate_control_variables
 from .base import validate_input
 
 __all__ = [
+    "capped_simplex_projection",
     "drop_nan_rows",
     "equations",
     "get_prox",
+    "get_regularization",
     "print_model",
     "prox_cad",
     "prox_l0",
     "prox_l1",
+    "reorder_constraints",
     "supports_multiple_targets",
     "validate_control_variables",
     "validate_input",
