@@ -154,6 +154,15 @@ def data_linear_oscillator_corrupted():
     return X, X_dot, trimming_array
 
 
+@pytest.fixture
+def data_linear_combination():
+    t = np.linspace(0, 5, 100)
+    x = np.stack((np.exp(t), np.sin(t), np.cos(t)), axis=-1)
+    y = np.stack((x[:, 0] + x[:, 1], x[:, 1] + x[:, 2]), axis=-1)
+
+    return x, y
+
+
 # Datasets with control inputs
 
 
